=== modified file 'lib/lp/soyuz/browser/queue.py'
--- lib/lp/soyuz/browser/queue.py	2011-07-26 08:51:39 +0000
+++ lib/lp/soyuz/browser/queue.py	2011-07-28 07:59:23 +0000
@@ -27,6 +27,7 @@
     load_referencing,
     load_related,
     )
+from lp.services.job.model.job import Job
 from lp.soyuz.enums import (
     PackagePublishingPriority,
     PackageUploadStatus,
@@ -190,6 +191,19 @@
         return getUtility(IPackagesetSet).getForPackages(
             self.context, set(spr.sourcepackagenameID for spr in sprs))
 
+    def loadPackageCopyJobs(self, uploads):
+        """Batch-load `PackageCopyJob`s and related information."""
+        # Avoid circular imports.
+        from lp.registry.model.person import Person
+        from lp.soyuz.model.archive import Archive
+        from lp.soyuz.model.packagecopyjob import PackageCopyJob
+
+        package_copy_jobs = load_related(
+            PackageCopyJob, uploads, ['package_copy_job_id'])
+        load_related(Archive, package_copy_jobs, ['source_archive_id'])
+        jobs = load_related(Job, package_copy_jobs, ['job_id'])
+        load_related(Person, jobs, ['requester_id'])
+
     def decoratedQueueBatch(self):
         """Return the current batch, converted to decorated objects.
 
@@ -245,6 +259,8 @@
 
         package_sets = self.getPackagesetsFor(source_sprs)
 
+        self.loadPackageCopyJobs(uploads)
+
         return [
             CompletePackageUpload(
                 item, build_upload_files, source_upload_files, package_sets)

=== modified file 'lib/lp/soyuz/browser/tests/test_queue.py'
--- lib/lp/soyuz/browser/tests/test_queue.py	2011-06-23 13:05:52 +0000
+++ lib/lp/soyuz/browser/tests/test_queue.py	2011-07-28 07:59:23 +0000
@@ -236,6 +236,11 @@
             view = self.makeView(upload.distroseries, queue_admin)
             html_text = view()
         self.assertIn(upload.package_name, html_text)
+        # The details section states the sync's origin and requester.
+        self.assertIn(
+            upload.package_copy_job.source_archive.displayname, html_text)
+        self.assertIn(
+            upload.package_copy_job.job.requester.displayname, html_text)
 
 
 class TestCompletePackageUpload(TestCaseWithFactory):

=== modified file 'lib/lp/soyuz/configure.zcml'
--- lib/lp/soyuz/configure.zcml	2011-07-28 09:26:39 +0000
+++ lib/lp/soyuz/configure.zcml	2011-07-28 14:46:35 +0000
@@ -181,6 +181,7 @@
                 is_delayed_copy
                 isPPA
                 package_copy_job
+                package_copy_job_id
                 package_name
                 package_version
                 section_name

=== modified file 'lib/lp/soyuz/templates/distroseries-queue.pt'
--- lib/lp/soyuz/templates/distroseries-queue.pt	2011-07-18 09:23:10 +0000
+++ lib/lp/soyuz/templates/distroseries-queue.pt	2011-07-28 07:59:23 +0000
@@ -239,6 +239,23 @@
       </tr>
     </tal:copy>
 
+    <tal:sync condition="packageupload/package_copy_job">
+      <tr>
+        <td />
+        <td tal:condition="view/availableActions" />
+        <td colspan="7">
+          Sync from
+          <tal:archive
+            content="packageupload/package_copy_job/source_archive/displayname">
+            Primary Archive for Ubuntu
+          </tal:archive>,
+          requested by
+          <tal:requester
+            content="structure packageupload/package_copy_job/job/requester/fmt:link" />
+        </td>
+      </tr>
+    </tal:sync>
+
     <tal:upload condition="not: packageupload/pending_delayed_copy">
       <tr tal:repeat="file packageupload/source_files">
         <td/>

